var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from 'react';
import { Polygon, Marker, Polyline } from 'react-native-maps';
import uuid from 'uuid';
import { flatten, makePoint, makeLine } from './helpers';
var makeOverlays = function (features) {
    var points = features
        .filter(function (f) {
        return f.geometry &&
            (f.geometry.type === 'Point' || f.geometry.type === 'MultiPoint');
    })
        .map(function (feature) {
        return makeCoordinates(feature).map(function (coordinates) {
            return makeOverlay(coordinates, feature);
        });
    })
        .reduce(flatten, [])
        .map(function (overlay) { return (__assign({}, overlay, { type: 'point' })); });
    var lines = features
        .filter(function (f) {
        return f.geometry &&
            (f.geometry.type === 'LineString' ||
                f.geometry.type === 'MultiLineString');
    })
        .map(function (feature) {
        return makeCoordinates(feature).map(function (coordinates) {
            return makeOverlay(coordinates, feature);
        });
    })
        .reduce(flatten, [])
        .map(function (overlay) { return (__assign({}, overlay, { type: 'polyline' })); });
    var multipolygons = features
        .filter(function (f) { return f.geometry && f.geometry.type === 'MultiPolygon'; })
        .map(function (feature) {
        return makeCoordinates(feature).map(function (coordinates) {
            return makeOverlay(coordinates, feature);
        });
    })
        .reduce(flatten, []);
    var polygons = features
        .filter(function (f) { return f.geometry && f.geometry.type === 'Polygon'; })
        .map(function (feature) { return makeOverlay(makeCoordinates(feature), feature); })
        .concat(multipolygons)
        .map(function (overlay) { return (__assign({}, overlay, { type: 'polygon' })); });
    return points.concat(lines).concat(polygons);
};
var makeOverlay = function (coordinates, feature) {
    var overlay = {
        feature: feature,
        id: feature.id ? feature.id : uuid()
    };
    if (feature.geometry.type === 'Polygon' ||
        feature.geometry.type === 'MultiPolygon') {
        if (coordinates.length > 1)
            return __assign({}, overlay, { coordinates: coordinates[0], holes: coordinates.slice(1) });
        return __assign({}, overlay, { coordinates: coordinates[0] });
    }
    return __assign({}, overlay, { coordinates: coordinates });
};
var makeCoordinates = function (feature) {
    var g = feature.geometry;
    var coordinates;
    switch (g.type) {
        case 'Point':
            coordinates = [makePoint(g.coordinates)];
            break;
        case 'MultiPoint':
            coordinates = g.coordinates.map(makePoint);
            break;
        case 'LineString':
            coordinates = [makeLine(g.coordinates)];
            break;
        case 'MultiLineString':
        case 'Polygon':
            coordinates = g.coordinates.map(makeLine);
            break;
        case 'MultiPolygon':
            coordinates = g.coordinates.map(function (p) { return p.map(makeLine); });
            break;
        default:
            coordinates = [];
            break;
    }
    return coordinates;
};
var Geojson = function (props) {
    var overlays = makeOverlays(props.geojson.features);
    return (React.createElement(React.Fragment, null, overlays.map(function (overlay) {
        if (overlay.type === 'point') {
            return (React.createElement(Marker, { key: overlay.id, coordinate: overlay.coordinates, pinColor: props.pinColor }));
        }
        if (overlay.type === 'polygon') {
            return (React.createElement(Polygon, { key: overlay.id, coordinates: overlay.coordinates, holes: overlay.holes, strokeColor: props.strokeColor, fillColor: props.fillColor, strokeWidth: props.strokeWidth }));
        }
        if (overlay.type === 'polyline') {
            return (React.createElement(Polyline, { key: overlay.id, coordinates: overlay.coordinates, strokeColor: props.strokeColor, strokeWidth: props.strokeWidth }));
        }
    })));
};
export { Geojson as default, makeOverlays };
